#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_STORE_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_STORE_HPP_INCLUDED

#include <boost/simd/memory/include/functions/store.hpp>

#endif
